@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.10 1999/05/27 23:15:56 martin Exp $ */
+/* $Id: procmap.c,v 1.16 2004/06/09 18:52:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,11 +22,12 @@
 */
 
 #include <locale.h>
+#include <libintl.h>
+#include <stdio.h>
 
 #include <glibtop.h>
 #include <glibtop/open.h>
 #include <glibtop/close.h>
-#include <glibtop/xmalloc.h>
 
 #include <glibtop/parameter.h>
 
@@ -58,9 +59,9 @@ main (int argc, char *argv [])
 	count = PROFILE_COUNT;
 
 	setlocale (LC_ALL, "");
-	bindtextdomain (PACKAGE, GTOPLOCALEDIR);
-	textdomain (PACKAGE);
-	
+	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
+	textdomain (GETTEXT_PACKAGE);
+
 	glibtop_init_r (&glibtop_global_server, 0, GLIBTOP_INIT_NO_OPEN);
 
 	glibtop_get_parameter (GLIBTOP_PARAM_METHOD, &method, sizeof (method));
@@ -96,7 +97,7 @@ main (int argc, char *argv [])
 		const char *filename = NULL;
 		unsigned device, device_major, device_minor;
 		char perm [5];
-		
+
 		if (maps [i].flags & (1L << GLIBTOP_MAP_ENTRY_FILENAME))
 			filename = maps [i].filename;
 
@@ -153,10 +154,10 @@ main (int argc, char *argv [])
 		}
 
 		if (filename && (filename != maps [i].filename))
-			glibtop_free (filename);
+			g_free ((void*)filename);
 	}
 
-	glibtop_free (maps);
+	g_free (maps);
 
 	glibtop_close ();
 
